## [1.1.0] - 2019-04-25

### Modified
-  patient-similarity against all patients in database if query patient has HPO term


## [1.0.0] - 2019-04-18

### Added
-  patient-similarity integration for phenotype scoring
